@@ -4,21 +4,55 @@ from datetime import datetime
 import sys
 #sys.path.append('C:\\Users\\coliveira\\OneDrive\\Coding\\Python\\MFToolbox\\')
 from mftoolbox import constants, funcs
+from selenium import webdriver
+from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 
-def nome_pregao(_ativo):
+def ultima_cotacao(_ticker):
     """
-    Busca no site Tradingview.com o nome de pregão de um ativo
+    Busca no site Tradingview.com o nome de pregão de um ativo, a última cotação, seu horário,
+    ganho monetário e percentual
 
     :param _ativo: código do ativo
-    :return: string com nome de pregão
+    :return: tuple [ticker, nome de pregão, cotacao, horario, variação monetária, variação percentual
     """
-    url = 'https://www.tradingview.com/symbols/' + _ativo
-    r = requests.get(url, headers=constants.Header.header)
-    soup = BeautifulSoup(r.text, 'lxml')
+    url = 'https://www.tradingview.com/symbols/' + _ticker
+
+    caps = DesiredCapabilities().CHROME
+    caps["pageLoadStrategy"] = "eager"
+    options = webdriver.ChromeOptions()
+    chrome_preferences = {'profile.managed_default_content_settings.images': 2}
+    options.add_argument("headless")
+    # noinspection SpellCheckingInspection
+    options.add_experimental_option("prefs", chrome_preferences)
+    browser = webdriver.Chrome(options=options, service_args=['--silent'], desired_capabilities=caps)
+    browser.get(url)
+    html = browser.page_source
+    soup = BeautifulSoup(html, "lxml")
     try:
-        return soup.findAll("div", {"class": "tv-symbol-header__long-title-first-text"})[0].text
-    except
-        return ""
+        nome_pregao = soup.findAll("div", {"class": "tv-symbol-header__long-title-first-text"})[0].text
+    except:
+        nome_pregao = ''
+    try:
+        cotacao = float(soup.findAll("div", {"class": "tv-symbol-price-quote__value js-symbol-last"})[0].text)
+    except:
+        cotacao = 0
+    try:
+        horario = soup.findAll("span", {"class": "js-symbol-lp-time"})[0].text.replace(')','').replace('(','')
+        horario = datetime.strptime(horario[:-6], '%b %d %H:%M')
+    except:
+        horario = ''
+    try:
+        variacao_monetaria = soup.findAll("span",
+                                          {"class": "js-symbol-change tv-symbol-price-quote__change-value"})[0].text
+    except:
+        variacao_monetaria = 0\
+    try:
+        variacao_percentual = soup.findAll("span",
+                                       {"class": "js-symbol-change-pt tv-symbol-price-quote__change-value"})[0].text
+    except:
+        variacao_percentual = 0
+
+    return [_ticker, nome_pregao, cotacao, horario, variacao_monetaria, variacao_percentual]
 
 
 def ultimo_pregao(_ativo):
